# Vacasa API
# Copyright 2018 John W. Miller
# See LICENSE for details.

"""
Spoonacular APIs library
"""
__version__ = '0.0.1'
__author__ = 'John W. Miller'
__description__ = 'A Python client for the Vacasa Connect API'
__license__ = 'MIT'

import sys
from .api import API



# Vacasa API
# Copyright 2018 John W. Miller
# See LICENSE for details.

"""
API details and documentation: https://vacasa.docs.stoplight.io/
"""

import requests
import socket
import time


class API(object):
    """Vacasa API"""

    # Create a persistent requests connection
    session = requests.Session()
    session.headers = {"Application": "vacasa_python_client"}

    def __init__(self, api_key, api_secret, timeout=5, sleep_time=1.5):
        """ Vacasa API Constructor

        :param api_key: API key provided by Vacasa (str)
        :param api_secret: API secret provided by Vacasa (str)
        :param timeout: time before quitting on response (seconds)
        :param sleep_time: time to wait between requests (seconds)
        :param allow_extra_calls: override the API call limit (bool)
        """

        assert api_key != '', 'Must supply a non-empty API key.'
        assert api_secret != '', 'Must supply a non-empty API secret.'
        self.auth = {'key': api_key, 'secret': api_secret}
        self.host = "connect.vacasa.com/"
        self.timeout = timeout
        self.sleep_time = max(sleep_time, 1)  # Rate limiting

    def _make_request(self, path,
                      method='GET',
                      query_=None,
                      params_=None,
                      json_=None):
        """ Make a request to the API """

        try:
            uri = self.api_root + path
            response = self.session.request(method, uri,
                                            timeout=self.timeout,
                                            data=query_,
                                            params=params_,
                                            json=json_)
        except socket.timeout as e:
            print("Timeout raised and caught: {}".format(e))
            return

        time.sleep(self.sleep_time)  # Enforce rate limiting
        return response



# Vacasa API
# Copyright 2018 John W. Miller
# See LICENSE for details.

import re
import os
from setuptools import find_packages, setup

VERSIONFILE = "vacasa/__init__.py"
ver_file = open(VERSIONFILE, "rt").read()
VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
mo = re.search(VSRE, ver_file, re.M)

if mo:
    version = mo.group(1)
else:
    raise RuntimeError(
        "Unable to find version string in {}".format(VERSIONFILE))

here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'README.md')) as f:
    README = f.read()

setup(name="vacasa",
      version=version,
      description="A Python client for the Vacasa Connect API",
      long_description=README,
      long_description_content_type="text/markdown",
      license="MIT",
      author="John W. Miller",
      url="https://github.com/johnwmillr/VacasaConnectAPI",
      packages=find_packages(exclude=['tests']),
      install_requires=["requests"],
      keywords="vacasa API home rental vacation property reality",
      python_requires=">=3.*",
      classifiers=[
              'Topic :: Software Development :: Libraries',
          'Operating System :: OS Independent',
          'Programming Language :: Python',
          'Programming Language :: Python :: 3',
      ])
